@@ -2,11 +2,16 @@ from sqlite3_api.utils import string, integer, list_, dict_
 
 
 class Table:
-
     @classmethod
     def get_types(cls):
-        vars_ = {}
+        _vars = {}
         for k, i in vars(cls).items():
             if not k.startswith('__'):
-                vars_[k] = i
-        return vars_
+                _vars[k] = i
+        return _vars
+
+    @classmethod
+    def get_fields(cls):
+        fields = [i for i in cls.get_types().keys()]
+        fields.remove('id')
+        return fields
