@@ -17,9 +17,15 @@ def dict_():
     return [" TEXT", 'dict']
 
 
-def add_quotes(value):
+def convert_from_data(value):
     if isinstance(value, str) or isinstance(value, list):
-        value = '"{}"'.format(str(value).replace('"', "'"))
+        value = '{}'.format(str(value).replace('``', '"'))
+    return value
+
+
+def convert_from_class(value):
+    if isinstance(value, str) or isinstance(value, list):
+        value = '"{}"'.format(str(value).replace('"', "``"))
     return value
 
 
@@ -27,12 +33,6 @@ def get_field(obj, field):
     return vars(obj)[field]
 
 
-def get_fields(obj):
-    fields = [i for i in obj.get_types().keys()]
-    fields.remove('id')
-    return fields
-
-
 def get_visual(obj):
     if type(obj).__name__ == 'list':
         return [[i for i in vars(obj_class).values()] for obj_class in obj]
